@@ -1,7 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="hu_HU">
-<defaultcodec>UTF-8</defaultcodec>
+<TS version="2.1" language="hu_HU">
 <context>
     <name>ClipGrab</name>
     <message>
@@ -10,22 +9,22 @@
         <translation>Automatikus nyelvfelismerés</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="504"/>
+        <location filename="clipgrab.cpp" line="514"/>
         <source>Downloading update … %1/%2 MBytes</source>
         <translation>Frissítés letöltése … %1/%2 MByte</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="513"/>
+        <location filename="clipgrab.cpp" line="523"/>
         <source>There was an error while downloading the update.: %1</source>
         <translation>Hiba történt a frissítés letöltése közben.: %1</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="527"/>
+        <location filename="clipgrab.cpp" line="537"/>
         <source>The fingerprint of the downloaded update file could not be verified: %1 should have been %2</source>
         <translation>Nem hitelesíthető a letöltött frissítés ellenörzőösszege: %1 helyett %2 kéne hogy legyen</translation>
     </message>
     <message>
-        <location filename="clipgrab.cpp" line="539"/>
+        <location filename="clipgrab.cpp" line="549"/>
         <source>Could not open update file.</source>
         <translation>Nem nyitható meg a frissítés.</translation>
     </message>
@@ -48,12 +47,11 @@
         <translation>Ennek a videónak a letöltéséhez be kell jelentkezned, vagy jóvá kell hagynod a hozzáférést.</translation>
     </message>
     <message>
-        <location filename="login_dialog.ui" line="100"/>
         <source>about:blank</source>
-        <translation>about:blank</translation>
+        <translation type="vanished">about:blank</translation>
     </message>
     <message>
-        <location filename="login_dialog.ui" line="124"/>
+        <location filename="login_dialog.ui" line="93"/>
         <source>Remember login</source>
         <translation>Emlékezzen rám</translation>
     </message>
@@ -61,148 +59,152 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="mainwindow.cpp" line="247"/>
-        <location filename="mainwindow.cpp" line="259"/>
+        <location filename="mainwindow.cpp" line="253"/>
         <source>Select Target</source>
         <translation>Mentés helyének kijelölése</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="329"/>
+        <location filename="mainwindow.cpp" line="333"/>
         <source>Please wait while ClipGrab is loading information about the video ...</source>
         <translation>Kérlek várj, míg a ClipGrab kielemzi a videót...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="346"/>
+        <location filename="mainwindow.cpp" line="350"/>
         <source>Please enter the link to the video you want to download in the field below.</source>
         <translation>Kezdéshez illeszd be a letölteni kívánt videó hivatkozását!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="351"/>
+        <location filename="mainwindow.cpp" line="355"/>
         <source>The link you have entered seems to not be recognised by any of the supported portals.&lt;br/&gt;Now ClipGrab will check if it can download a video from that site anyway.</source>
         <translation>A megadott hivatkozás nem felismerhető, vagy nem támogatott.&lt;br/&gt;Now ClipGrab will check if it can download a video from that site anyway.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="398"/>
+        <location filename="mainwindow.cpp" line="402"/>
         <source>No downloadable video could be found.&lt;br /&gt;Maybe you have entered the wrong link or there is a problem with your connection.</source>
         <translation>Nem található letölthető tartalom.&lt;br /&gt;A hivatkozás hibás lehet, vagy probléma merült fel az internetkapcsolatodban.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="411"/>
+        <location filename="mainwindow.cpp" line="415"/>
         <source>ClipGrab - Select target path</source>
         <translation>ClipGrab - Mentés helyének kijelölése</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="456"/>
+        <location filename="mainwindow.cpp" line="460"/>
         <source>ClipGrab: Video discovered in your clipboard</source>
         <translation>ClipGrab: Videó észlelve a vágólapon</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="456"/>
+        <location filename="mainwindow.cpp" line="460"/>
         <source>ClipGrab has discovered the address of a compatible video in your clipboard. Click on this message to download it now.</source>
         <translation>A ClipGrab felismert a vágólapon egy hivatkozását. Kattints erre az üzenetre a letöltés azonnali megkezdéséhez!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="562"/>
+        <location filename="mainwindow.cpp" line="566"/>
         <source>ClipGrab - Exit confirmation</source>
         <translation>ClipGrab - Kilépés megerősítése</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="562"/>
+        <location filename="mainwindow.cpp" line="566"/>
         <source>There is still at least one download in progress.&lt;br /&gt;If you exit the program now, all downloads will be canceled and cannot be recovered later.&lt;br /&gt;Do you really want to quit ClipGrab now?</source>
         <translation>Egy, vagy több művelet folyamatban van.&lt;br /&gt;Ha most kilépsz minden művelet megszakad végleg és nem lesz folytatható.&lt;br /&gt;Biztos vagy benne, hogy kilépsz a ClipGrab-ből?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="599"/>
+        <location filename="mainwindow.cpp" line="603"/>
         <source>Download finished</source>
         <translation>Letöltés befejeződött</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="599"/>
+        <location filename="mainwindow.cpp" line="603"/>
         <source>Downloading and converting “%title” is now finished.</source>
         <translation>A(z) “%title” letöltése és átalakítása befejeződött.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="603"/>
+        <location filename="mainwindow.cpp" line="607"/>
         <source>All downloads finished</source>
         <translation>Minden letöltés befejeződött</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="603"/>
+        <location filename="mainwindow.cpp" line="607"/>
         <source>ClipGrab has finished downloading and converting all selected videos.</source>
         <translation>A ClipGrab minden listán szereplő műveletet befejezett.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="668"/>
-        <location filename="mainwindow.cpp" line="670"/>
-        <location filename="mainwindow.cpp" line="677"/>
-        <location filename="mainwindow.cpp" line="679"/>
+        <location filename="mainwindow.cpp" line="672"/>
+        <location filename="mainwindow.cpp" line="674"/>
+        <location filename="mainwindow.cpp" line="681"/>
+        <location filename="mainwindow.cpp" line="683"/>
         <source>ClipGrab</source>
         <translation>ClipGrab</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="668"/>
-        <location filename="mainwindow.cpp" line="670"/>
+        <location filename="mainwindow.cpp" line="672"/>
+        <location filename="mainwindow.cpp" line="674"/>
         <source> MiB</source>
         <translation> MB</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="670"/>
+        <location filename="mainwindow.cpp" line="674"/>
         <source> KiB</source>
         <translation> KB</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="677"/>
-        <location filename="mainwindow.cpp" line="679"/>
+        <location filename="mainwindow.cpp" line="681"/>
+        <location filename="mainwindow.cpp" line="683"/>
         <source>Currently no downloads in progress.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="680"/>
+        <location filename="mainwindow.cpp" line="684"/>
         <source>ClipGrab - Download and Convert Online Videos</source>
         <translation>ClipGrab - Internetes videók letöltése és átalakítása</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="872"/>
+        <location filename="mainwindow.cpp" line="846"/>
+        <source>No results found.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="913"/>
         <source>&amp;Open downloaded file</source>
         <translation>Letöltött fájl megnyitása (&amp;o)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="873"/>
+        <location filename="mainwindow.cpp" line="914"/>
         <source>Open &amp;target folder</source>
         <translation>Célkönyv&amp;tár megnyitása</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="875"/>
+        <location filename="mainwindow.cpp" line="916"/>
         <source>&amp;Pause download</source>
         <translation>Letöltés szüneteltetése (&amp;p)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="876"/>
+        <location filename="mainwindow.cpp" line="917"/>
         <source>&amp;Restart download</source>
         <translation>Letöltés új&amp;raindítása</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="877"/>
+        <location filename="mainwindow.cpp" line="918"/>
         <source>&amp;Cancel download</source>
         <translation>Letöltés megszakítása (&amp;c)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="879"/>
+        <location filename="mainwindow.cpp" line="920"/>
         <source>Copy &amp;video link</source>
         <translation>&amp;Videó linkjének másolása</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="880"/>
+        <location filename="mainwindow.cpp" line="921"/>
         <source>Open video link in &amp;browser</source>
         <translation>Videó megnyitása a &amp;böngészőben</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="885"/>
+        <location filename="mainwindow.cpp" line="926"/>
         <source>Resume download</source>
         <translation>Letöltés folytatása</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="894"/>
+        <location filename="mainwindow.cpp" line="936"/>
         <source>Show in &amp;Finder</source>
         <translation>Megjelenítés a keresőben (&amp;f)</translation>
     </message>
@@ -225,72 +227,71 @@
         <translation>Írj be kulcsszavakat YouTube-on való kereséshez!</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="179"/>
         <source>about:blank</source>
-        <translation>about:blank</translation>
+        <translation type="vanished">about:blank</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="188"/>
+        <location filename="mainwindow.ui" line="189"/>
         <source>Downloads</source>
         <translation>Letöltés</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="197"/>
+        <location filename="mainwindow.ui" line="198"/>
         <source>Grab this clip!</source>
         <translation>Letöltés</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="226"/>
+        <location filename="mainwindow.ui" line="227"/>
         <source>Quality:</source>
         <translation>Minőség:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="242"/>
+        <location filename="mainwindow.ui" line="243"/>
         <source>Please enter the link to the video you want to download in the field below.</source>
         <translation>Másold be a letölteni kívánt videó hivatkozását!</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="277"/>
+        <location filename="mainwindow.ui" line="278"/>
         <source>Format:</source>
         <translation>Formátum:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="316"/>
+        <location filename="mainwindow.ui" line="317"/>
         <source>Current Downloads:</source>
         <translation>Folyamatban lévő letöltések:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="326"/>
+        <location filename="mainwindow.ui" line="327"/>
         <source>Cancel selected download</source>
         <translation>Kijelölt letöltések megszakítása</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="336"/>
+        <location filename="mainwindow.ui" line="337"/>
         <source>Open the target folder of the selected download</source>
         <translation>Célkönyvtár megnyitása</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="356"/>
+        <location filename="mainwindow.ui" line="357"/>
         <source>Portal</source>
         <translation>Forrás</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="361"/>
+        <location filename="mainwindow.ui" line="362"/>
         <source>Title</source>
         <translation>Cím</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="366"/>
+        <location filename="mainwindow.ui" line="367"/>
         <source>Format</source>
         <translation>Formátum</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="371"/>
+        <location filename="mainwindow.ui" line="372"/>
         <source>Progress</source>
         <translation>Állapot</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="382"/>
+        <location filename="mainwindow.ui" line="383"/>
         <source>Pause selected download</source>
         <translation>Kijelölt letöltések szüneteltetése</translation>
     </message>
@@ -299,296 +300,296 @@
         <translation type="obsolete">…</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="394"/>
+        <location filename="mainwindow.ui" line="395"/>
         <source>Settings</source>
         <translation>Beállítások</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="407"/>
+        <location filename="mainwindow.ui" line="408"/>
         <source>General</source>
         <translation>Általános</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="431"/>
+        <location filename="mainwindow.ui" line="432"/>
         <source>Here you can adjust some general settings concerning the behaviour of ClipGrab.</source>
         <translation>Itt módosíthatod a ClipGrab alapvető beállításait</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="442"/>
+        <location filename="mainwindow.ui" line="443"/>
         <source>Target Path</source>
         <translation>Mentés helye</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="448"/>
+        <location filename="mainwindow.ui" line="449"/>
         <source>Always save at the last used path.</source>
         <translation>Utoljára használt könyvtár megjegyzése</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="462"/>
+        <location filename="mainwindow.ui" line="463"/>
         <source>Here you can configure where the downloaded videos are to be saved.</source>
         <translation>Itt adhatod meg, hogy hova mentse a program a letöltött videókat</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="469"/>
+        <location filename="mainwindow.ui" line="470"/>
         <source>Browse ...</source>
         <translation>Tallózás...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="476"/>
+        <location filename="mainwindow.ui" line="477"/>
         <source>Never ask for file name</source>
         <translation>Fájl automatikus elnevezése</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="497"/>
+        <location filename="mainwindow.ui" line="498"/>
         <source>Metadata</source>
         <translation>Metaadat</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="503"/>
+        <location filename="mainwindow.ui" line="504"/>
         <source>Here you can configure if ClipGrab is supposed to add metadata (ID3 tags) to your mp3 files.</source>
         <translation>Itt állíthatod be, hogy ClipGrab mellékeljen-e metaadatokat (ID3-címkét) a letöltött mp3 formátumú fájlokhoz</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="510"/>
+        <location filename="mainwindow.ui" line="511"/>
         <source>Use metadata</source>
         <translation>Metaadat írása</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="531"/>
+        <location filename="mainwindow.ui" line="532"/>
         <source>Clipboard</source>
         <translation>Vágólap</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="537"/>
+        <location filename="mainwindow.ui" line="538"/>
         <source>Here you can configure how ClipGrab behaves when a downloadable video is discovered in your clipboard.</source>
         <translation>Itt állíthatod be, hogy a ClipGrab hogyan kezelje a vágólapon lévő hivatkozásokat</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="544"/>
+        <location filename="mainwindow.ui" line="545"/>
         <source>Always download</source>
         <translation>Azonnali letöltés</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="551"/>
+        <location filename="mainwindow.ui" line="552"/>
         <source>Never download</source>
         <translation>Ne töltse le</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="558"/>
+        <location filename="mainwindow.ui" line="559"/>
         <source>Always ask</source>
         <translation>Kérdezzen meg</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="579"/>
+        <location filename="mainwindow.ui" line="580"/>
         <source>Notifications</source>
         <translation>Értesítések</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="585"/>
+        <location filename="mainwindow.ui" line="586"/>
         <source>After each download</source>
         <translation>Minden egyes letöltés után</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="592"/>
+        <location filename="mainwindow.ui" line="593"/>
         <source>After all downloads have been completed</source>
         <translation>Minden letöltés befejezése után</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="612"/>
+        <location filename="mainwindow.ui" line="613"/>
         <source>Here you can configure when ClipGrab is supposed to display notifications.</source>
         <translation>Itt állíthatod be, hogy hogyan értesítsen a ClipGrab a letöltésekről</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="619"/>
+        <location filename="mainwindow.ui" line="620"/>
         <source>Never</source>
         <translation>Soha</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="627"/>
+        <location filename="mainwindow.ui" line="628"/>
         <source>Proxy</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="633"/>
+        <location filename="mainwindow.ui" line="634"/>
         <source>Use a proxy server</source>
         <translation>Proxy-szerver használata</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="643"/>
+        <location filename="mainwindow.ui" line="644"/>
         <source>Proxy settings</source>
         <translation>Proxy beállításai</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="652"/>
+        <location filename="mainwindow.ui" line="653"/>
         <source>Hostname/IP:</source>
         <translation>KIszolgáló:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="659"/>
+        <location filename="mainwindow.ui" line="660"/>
         <source>Port:</source>
         <translation>Port:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="686"/>
+        <location filename="mainwindow.ui" line="687"/>
         <source>Proxy type:</source>
         <translation>Proxy típusa:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="694"/>
+        <location filename="mainwindow.ui" line="695"/>
         <source>HTTP Proxy</source>
         <translation>HTTP proxy</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="699"/>
+        <location filename="mainwindow.ui" line="700"/>
         <source>Socks5 Proxy</source>
         <translation>Socks5 proxy</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="726"/>
+        <location filename="mainwindow.ui" line="727"/>
         <source>Proxy authentication</source>
         <translation>Hitelesítési adatok</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="732"/>
+        <location filename="mainwindow.ui" line="733"/>
         <source>Username:</source>
         <translation>Felhasználónév:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="749"/>
+        <location filename="mainwindow.ui" line="750"/>
         <source>Password:</source>
         <translation>Jelszó:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="762"/>
+        <location filename="mainwindow.ui" line="763"/>
         <source>Proxy requires authentication</source>
         <translation>Hitelesítés használata</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="770"/>
+        <location filename="mainwindow.ui" line="771"/>
         <source>Other</source>
         <translation>Egyéb</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="797"/>
+        <location filename="mainwindow.ui" line="798"/>
         <source>Remove finished downloads from list</source>
         <translation>Befejezett letöltések eltávolítása a listáról</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="776"/>
+        <location filename="mainwindow.ui" line="777"/>
         <source>Minimize ClipGrab to the system tray</source>
         <translation>ClipGrab küldése tálcára kicsinyítéskor</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="783"/>
+        <location filename="mainwindow.ui" line="784"/>
         <source>Use WebM if possible</source>
         <translation>WebM formátum használata amikor csak lehetséges</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="790"/>
+        <location filename="mainwindow.ui" line="791"/>
         <source>Ignore SSL errors</source>
         <translation>SSL hibák figyelmen kívül hagyása</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="817"/>
+        <location filename="mainwindow.ui" line="818"/>
         <source>Remember logins</source>
         <translation>Emlékezzen a bejelentkezésekre</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="824"/>
+        <location filename="mainwindow.ui" line="825"/>
         <source>Remember video quality</source>
         <translation>Emlékezzen a videóminőségre</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="836"/>
+        <location filename="mainwindow.ui" line="837"/>
         <source>Language</source>
         <translation>Nyelv</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="860"/>
+        <location filename="mainwindow.ui" line="861"/>
         <source>Here you can change the language of ClipGrab.</source>
         <translation>Itt állíthatod be a ClipGrab felületének nyelvét.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="867"/>
+        <location filename="mainwindow.ui" line="868"/>
         <source>Please select a language from the list below. You have to restart ClipGrab in order to apply you selection.</source>
         <translation>Kérlek, válassz nyelvet! A beállítás a program újraindítása után lép életbe.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="904"/>
+        <location filename="mainwindow.ui" line="905"/>
         <source>Conversion</source>
         <translation>Átalakítás</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="927"/>
+        <location filename="mainwindow.ui" line="928"/>
         <source>Experts can create custom presets for the video conversion here.</source>
         <translation>Hozzáértők itt állíthatnak be egyedi profilokat átalakításhoz.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="934"/>
+        <location filename="mainwindow.ui" line="935"/>
         <source>Format preset</source>
         <translation>Átalakítási profil</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="944"/>
+        <location filename="mainwindow.ui" line="945"/>
         <source>Add new preset</source>
         <translation>Profil létrehozása</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="951"/>
+        <location filename="mainwindow.ui" line="952"/>
         <source>Remove selected preset</source>
         <translation>Profil törlése</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="974"/>
+        <location filename="mainwindow.ui" line="975"/>
         <source>Audio</source>
         <translation>Hang</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="986"/>
-        <location filename="mainwindow.ui" line="1038"/>
+        <location filename="mainwindow.ui" line="987"/>
+        <location filename="mainwindow.ui" line="1039"/>
         <source>Codec</source>
         <translation>Kódoló</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1012"/>
-        <location filename="mainwindow.ui" line="1100"/>
+        <location filename="mainwindow.ui" line="1013"/>
+        <location filename="mainwindow.ui" line="1101"/>
         <source>Bitrate (kb/s)</source>
         <translation>BItsűrűség (kb/s)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1019"/>
+        <location filename="mainwindow.ui" line="1020"/>
         <source>Disable Audio</source>
         <translation>Hang letiltása</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1029"/>
+        <location filename="mainwindow.ui" line="1030"/>
         <source>Video</source>
         <translation>Kép</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1051"/>
+        <location filename="mainwindow.ui" line="1052"/>
         <source>Frames/second</source>
         <translation>Képsebesség</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1110"/>
+        <location filename="mainwindow.ui" line="1111"/>
         <source>Disable video</source>
         <translation>Videó letiltása</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1125"/>
+        <location filename="mainwindow.ui" line="1126"/>
         <source>About</source>
         <translation>Névjegy</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1131"/>
+        <location filename="mainwindow.ui" line="1132"/>
         <source>&lt;h2&gt;Support ClipGrab!&lt;/h2&gt;
 &lt;p&gt;Only with your support, ClipGrab can remain free software!&lt;br&gt;So if you like ClipGrab and also want to help ensuring its further development, please consider making a donation.&lt;/p&gt;</source>
         <translation>&lt;h2&gt;Támogass!&lt;/h2&gt;
 &lt;p&gt;A ClipGrab támogatásotokkal maradhat a jövőben is ingyenes.&lt;br&gt;Ha a program elnyerte tetszésetek, és szeretnétek biztosítani a fejlesztését, kérlek, adományozzatok!&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1174"/>
+        <location filename="mainwindow.ui" line="1175"/>
         <source>&lt;h2&gt;Translation&lt;/h2&gt;
 ClipGrab is already available in many languages. If ClipGrab has not been translated into your language yet and if you want to contribute a translation, please check &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; for further information.</source>
         <translation>&lt;h2&gt;Fordítás&lt;/h2&gt;
@@ -596,7 +597,7 @@ A ClipGrab magyar fordítását karbantartja: Kádár Iván. Ha hibát találsz,
 Ha más nyelvre szeretnéd lefordítani a programot, látogasd meg a &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; oldalt további tudnivalókért!</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1191"/>
+        <location filename="mainwindow.ui" line="1192"/>
         <source>&lt;h2&gt;Thanks&lt;/h2&gt;
 ClipGrab relies on the work of the Qt project and the ffmpeg team.&lt;br&gt;
 Visit &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt; and &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt; for further information.</source>
@@ -650,37 +651,37 @@ p, li { white-space: pre-wrap; }
         <translation>ClipGrab frissítése</translation>
     </message>
     <message>
-        <location filename="update_message.ui" line="69"/>
+        <location filename="update_message.ui" line="116"/>
         <source>ClipGrab %1 is now available (you are using %2). Would you like to install the update?</source>
         <translation>Elérhető Clipgrab verzió: %1 (telepített verzió: %2) Szeretnéd feltenni a frissítést?</translation>
     </message>
     <message>
-        <location filename="update_message.ui" line="83"/>
+        <location filename="update_message.ui" line="130"/>
         <source>There is an update for your version of ClipGrab!</source>
         <translation>Eléhető egy frissítés a ClipGrab-hez!</translation>
     </message>
     <message>
-        <location filename="update_message.ui" line="183"/>
+        <location filename="update_message.ui" line="64"/>
         <source>Skip this update</source>
         <translation>Frissítés kihagyása</translation>
     </message>
     <message>
-        <location filename="update_message.ui" line="193"/>
+        <location filename="update_message.ui" line="91"/>
         <source>Download update</source>
         <translation>Frissítés letöltése</translation>
     </message>
     <message>
-        <location filename="update_message.ui" line="204"/>
+        <location filename="update_message.ui" line="240"/>
         <source>about:blank</source>
         <translation>about:blank</translation>
     </message>
     <message>
-        <location filename="update_message.ui" line="212"/>
+        <location filename="update_message.ui" line="74"/>
         <source>Remind me later</source>
         <translation>Emlékeztessen később</translation>
     </message>
     <message>
-        <location filename="update_message.ui" line="229"/>
+        <location filename="update_message.ui" line="41"/>
         <source>The update will begin in just a moment …</source>
         <translation>A frissítés pár pillanat múlva elkezdődik...</translation>
     </message>
@@ -775,12 +776,12 @@ Nagy felbontású videók letöltése így nem lehetséges.</translation>
         <translation>Értesítés</translation>
     </message>
     <message>
-        <location filename="message_dialog.ui" line="35"/>
+        <location filename="message_dialog.ui" line="48"/>
         <source>Close this message</source>
         <translation>Üzenet bezárása</translation>
     </message>
     <message>
-        <location filename="message_dialog.ui" line="62"/>
+        <location filename="message_dialog.ui" line="71"/>
         <source>about:blank</source>
         <translation>about:blank</translation>
     </message>
@@ -860,27 +861,27 @@ Nagy felbontású videók letöltése így nem lehetséges.</translation>
 <context>
     <name>video_dailymotion</name>
     <message>
-        <location filename="video_dailymotion.cpp" line="85"/>
+        <location filename="video_dailymotion.cpp" line="73"/>
         <source>HD (1080p)</source>
         <translation>Nagy felbontású (1080p)</translation>
     </message>
     <message>
-        <location filename="video_dailymotion.cpp" line="86"/>
+        <location filename="video_dailymotion.cpp" line="74"/>
         <source>HD (720p)</source>
         <translation>Nagy felbontású (720)</translation>
     </message>
     <message>
-        <location filename="video_dailymotion.cpp" line="87"/>
+        <location filename="video_dailymotion.cpp" line="75"/>
         <source>480p</source>
         <translation>480p</translation>
     </message>
     <message>
-        <location filename="video_dailymotion.cpp" line="88"/>
+        <location filename="video_dailymotion.cpp" line="76"/>
         <source>380p</source>
         <translation>380p</translation>
     </message>
     <message>
-        <location filename="video_dailymotion.cpp" line="89"/>
+        <location filename="video_dailymotion.cpp" line="77"/>
         <source>240p</source>
         <translation>240p</translation>
     </message>
@@ -896,15 +897,15 @@ Nagy felbontású videók letöltése így nem lehetséges.</translation>
 <context>
     <name>video_facebook</name>
     <message>
-        <location filename="video_facebook.cpp" line="111"/>
-        <location filename="video_facebook.cpp" line="112"/>
-        <location filename="video_facebook.cpp" line="141"/>
+        <location filename="video_facebook.cpp" line="161"/>
+        <location filename="video_facebook.cpp" line="162"/>
+        <location filename="video_facebook.cpp" line="191"/>
         <source>HD</source>
         <translation>Nagy felbontású</translation>
     </message>
     <message>
-        <location filename="video_facebook.cpp" line="113"/>
-        <location filename="video_facebook.cpp" line="114"/>
+        <location filename="video_facebook.cpp" line="163"/>
+        <location filename="video_facebook.cpp" line="164"/>
         <source>normal</source>
         <translation>normál minőség</translation>
     </message>
@@ -958,45 +959,45 @@ Nagy felbontású videók letöltése így nem lehetséges.</translation>
 <context>
     <name>video_youtube</name>
     <message>
-        <location filename="video_youtube.cpp" line="150"/>
+        <location filename="video_youtube.cpp" line="144"/>
         <source>HD (1080p)</source>
         <translation>HD (1080p)</translation>
     </message>
     <message>
-        <location filename="video_youtube.cpp" line="154"/>
+        <location filename="video_youtube.cpp" line="148"/>
         <source>HD (1440p)</source>
         <translation>HD (1440p)</translation>
     </message>
     <message>
-        <location filename="video_youtube.cpp" line="158"/>
+        <location filename="video_youtube.cpp" line="152"/>
         <source>4K (2160p)</source>
         <translation>4K (2160p)</translation>
     </message>
     <message>
-        <location filename="video_youtube.cpp" line="162"/>
+        <location filename="video_youtube.cpp" line="156"/>
         <source>5K (2880p)</source>
         <translation>5K (2880p)</translation>
     </message>
     <message>
-        <location filename="video_youtube.cpp" line="166"/>
+        <location filename="video_youtube.cpp" line="160"/>
         <source>8K (4320p)</source>
         <translation>8K (4320p)</translation>
     </message>
     <message>
-        <location filename="video_youtube.cpp" line="169"/>
+        <location filename="video_youtube.cpp" line="163"/>
         <source>8K (4320p60)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="video_youtube.cpp" line="488"/>
-        <location filename="video_youtube.cpp" line="519"/>
-        <location filename="video_youtube.cpp" line="615"/>
-        <location filename="video_youtube.cpp" line="618"/>
+        <location filename="video_youtube.cpp" line="481"/>
+        <location filename="video_youtube.cpp" line="512"/>
+        <location filename="video_youtube.cpp" line="611"/>
+        <location filename="video_youtube.cpp" line="614"/>
         <source>Original</source>
         <translation>Eredeti minőség</translation>
     </message>
     <message>
-        <location filename="video_youtube.cpp" line="671"/>
+        <location filename="video_youtube.cpp" line="663"/>
         <source>normal</source>
         <translation>normál minőség</translation>
     </message>
